@@ -8,12 +8,12 @@
 
 import os
 import sys
-sys.path.insert(0, os.path.abspath('../../src/'))
+sys.path.insert(0, os.path.abspath('../../src/sfrout'))
 
-project = 'SFR'
+project = 'sfrout'
 copyright = '2023, Lukasz Hoszowski'
 author = 'Lukasz Hoszowski'
-release = '0.1.3'
+release = '0.0.7'
 
 # -- General configuration ---------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration
